This function builds a valid projections object from some input
simulations and dates.
build_projections(x, dates = NULL, cumulative = FALSE, order_dates = TRUE)A matrix of simulated incidence stored as integers, where
rows correspond to dates and columns to simulations.
A vector of dates containing one value per row in x;
acceptable formats are: integer, Date, and POSIXct; if
NULL, the time steps will be counted, with the first dates corresponding to
0.
A logical indicating if data represent cumulative
incidence; defaults to FALSE.
A logical indicating whether the dates should be ordered,
from the oldest to the most recent one; TRUE by default.
Thibaut Jombart thibautjombart@gmail.com
the project function to generate the 'projections'
objects.